@@ -81,11 +81,6 @@ class QueryFpShotJobListRequest(RpcRequest):
 
 	def set_PipelineId(self, PipelineId):  # String
 		self.add_query_param('PipelineId', PipelineId)
-	def get_PrimaryKeyList(self): # String
-		return self.get_query_params().get('PrimaryKeyList')
-
-	def set_PrimaryKeyList(self, PrimaryKeyList):  # String
-		self.add_query_param('PrimaryKeyList', PrimaryKeyList)
 	def get_JobIds(self): # String
 		return self.get_query_params().get('JobIds')
 
