@@ -31,6 +31,11 @@ class SubmitMediaCensorJobRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_ExternalUrl(self): # String
+		return self.get_query_params().get('ExternalUrl')
+
+	def set_ExternalUrl(self, ExternalUrl):  # String
+		self.add_query_param('ExternalUrl', ExternalUrl)
 	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
