@@ -36,16 +36,31 @@ class UpdateSmarttagTemplateRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_KnowledgeConfig(self): # String
+		return self.get_query_params().get('KnowledgeConfig')
+
+	def set_KnowledgeConfig(self, KnowledgeConfig):  # String
+		self.add_query_param('KnowledgeConfig', KnowledgeConfig)
 	def get_Industry(self): # String
 		return self.get_query_params().get('Industry')
 
 	def set_Industry(self, Industry):  # String
 		self.add_query_param('Industry', Industry)
+	def get_LabelVersion(self): # String
+		return self.get_query_params().get('LabelVersion')
+
+	def set_LabelVersion(self, LabelVersion):  # String
+		self.add_query_param('LabelVersion', LabelVersion)
 	def get_Scene(self): # String
 		return self.get_query_params().get('Scene')
 
 	def set_Scene(self, Scene):  # String
 		self.add_query_param('Scene', Scene)
+	def get_FaceCustomParamsConfig(self): # String
+		return self.get_query_params().get('FaceCustomParamsConfig')
+
+	def set_FaceCustomParamsConfig(self, FaceCustomParamsConfig):  # String
+		self.add_query_param('FaceCustomParamsConfig', FaceCustomParamsConfig)
 	def get_TemplateName(self): # String
 		return self.get_query_params().get('TemplateName')
 
@@ -61,6 +76,16 @@ class UpdateSmarttagTemplateRequest(RpcRequest):
 
 	def set_FaceCategoryIds(self, FaceCategoryIds):  # String
 		self.add_query_param('FaceCategoryIds', FaceCategoryIds)
+	def get_KeywordConfig(self): # String
+		return self.get_query_params().get('KeywordConfig')
+
+	def set_KeywordConfig(self, KeywordConfig):  # String
+		self.add_query_param('KeywordConfig', KeywordConfig)
+	def get_LandmarkGroupIds(self): # String
+		return self.get_query_params().get('LandmarkGroupIds')
+
+	def set_LandmarkGroupIds(self, LandmarkGroupIds):  # String
+		self.add_query_param('LandmarkGroupIds', LandmarkGroupIds)
 	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
@@ -71,6 +96,11 @@ class UpdateSmarttagTemplateRequest(RpcRequest):
 
 	def set_OwnerAccount(self, OwnerAccount):  # String
 		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_ObjectGroupIds(self): # String
+		return self.get_query_params().get('ObjectGroupIds')
+
+	def set_ObjectGroupIds(self, ObjectGroupIds):  # String
+		self.add_query_param('ObjectGroupIds', ObjectGroupIds)
 	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
@@ -86,3 +116,8 @@ class UpdateSmarttagTemplateRequest(RpcRequest):
 
 	def set_AnalyseTypes(self, AnalyseTypes):  # String
 		self.add_query_param('AnalyseTypes', AnalyseTypes)
+	def get_LabelType(self): # String
+		return self.get_query_params().get('LabelType')
+
+	def set_LabelType(self, LabelType):  # String
+		self.add_query_param('LabelType', LabelType)
